"""
Task:
File paper.txt contains information about collecting waste paper - when and who 
brought what amount. Write a program which reads this file and calculates the total
amount of paper collected by each individual person. Then it will print the result
to the standard output (the people will be sorted alphabetically).

Sample output:  
Alice: 15.0
Bob: 28.0
Cyril: 19.5
Dana: 20.0
Emil: 7.5
Filip: 8.0
Gertruda: 24.0
Hanka: 27.5
Ivan: 20.0
John: 22.0

Bonus: 
Modify the program, so that it prints the people sorted by the collected amount (from the greatest to the least).
"""

from collections import defaultdict


paper = defaultdict(lambda: 0.0)

# lambda functions -> 
# https://realpython.com/python-lambda/

# defaultdict -> 
# https://www.accelebrate.com/blog/using-defaultdict-python
# https://docs.python.org/3.7/library/collections.html#defaultdict-objects

with open('paper.txt') as r:
    r.readline()  # Ignore the first line
    for line in r:
        date, name, amount = line.strip().split(',')
        name = name.strip()
        amount = float(amount)
        if name not in paper:
            paper[name] = 0.0
        paper[name] += amount

for name, amount in sorted(paper.items(), key = (lambda item: item[1]), reverse=True):
    print(f'{name}: {amount}')
