"""
Task:
Alice throws a dice 10 times. What is the probability, that there will be 
at least 4 sixes out of the 10 throws? Solve this problem by a simulation, 
i.e. generate 10 random throws (use module random) and decide whether there 
are at least 4 sixes. Repeat this 10000 times and calculate the percentage
of successful trials.
(The correct result is around 7%; the result of the simulation will of course 
be a bit different every time.)

Bonus:
Bob throws a dice 100 times. What is the probability, that there will be 
at least 4 sixes IN A ROW?
(The correct result is around 6%.)
"""

import random
import math


def simulate_4x6(n_throws: int) -> bool:
    """Simulate n_throws throws and return True, iff there were at least 4 sixes."""
    throws = [random.randint(1, 6) for i in range(n_throws)]
    return throws.count(6) >= 4

def simulate_4x6_in_a_row(n_throws: int) -> bool:
    """Simulate n_throws throws and return True, iff there were at least 4 sixes in a row."""
    throws = [random.randint(1, 6) for i in range(n_throws)]
    throws_string = ''.join(str(x) for x in throws)
    return '6666' in throws_string


n_simulations = 10000
n_successes_Alice = 0
n_successes_Bob = 0

for i in range(n_simulations):
    if simulate_4x6(10):
        n_successes_Alice += 1

probability_Alice = n_successes_Alice / n_simulations

for i in range(n_simulations):
    if simulate_4x6_in_a_row(100):
        n_successes_Bob += 1

probability_Bob = n_successes_Bob / n_simulations

print(f'Probability - Alice: {probability_Alice}')
print(f'Probability - Bob: {probability_Bob}')
